@@ -40,6 +40,7 @@ class BaseActor:
         self.centro_x = 0
         self.centro_y = 0
         self._espejado = False
+        self.fijo = 0
 
     def definir_centro(self, x, y):
         self.centro_x = x
@@ -169,6 +170,9 @@ class QtGrilla(QtImagen):
 
 class QtTexto(QtImagen):
 
+    def __init__(self, texto, magnitud, motor):
+        self._ancho, self._alto = motor.obtener_area_de_texto(texto, magnitud)
+
     def _dibujar_pixmap(self, motor, dx, dy):
         nombre_de_fuente = motor.canvas.font().family()
         fuente = QtGui.QFont(nombre_de_fuente, self.magnitud)
@@ -180,9 +184,15 @@ class QtTexto(QtImagen):
         lines = self.texto.split('\n')
 
         for line in lines:
-            motor.canvas.drawText(dx, dy, line)
+            motor.canvas.drawText(dx, dy + self._alto, line)
             dy += metrica.height()
 
+    def ancho(self):
+        return self._ancho
+
+    def alto(self):
+        return self._alto
+
 
 class QtLienzo(QtImagen):
 
@@ -375,10 +385,18 @@ class QtActor(BaseActor):
 
     def dibujar(self, motor):
         escala_x, escala_y = self._escala, self._escala
+
         if self._espejado:
             escala_x *= -1
 
-        self.imagen.dibujar(motor, self.x, self.y, 
+        if not self.fijo:
+            x = self.x - motor.camara_x
+            y = self.y - motor.camara_y
+        else:
+            x = self.x
+            y = self.y
+
+        self.imagen.dibujar(motor, x, y,
                 self.centro_x, self.centro_y,
                 escala_x, escala_y, self._rotacion, self._transparencia)
 
@@ -454,10 +472,6 @@ class SFMLCanvas:
         self.render(event, self.canvas)
         self.canvas.end()
 
-
-
-
-
     def keyPressEvent(self, event):
         print "Pulsa la tecla:", event.key()
 
@@ -482,6 +496,8 @@ class QtBase(motor.Motor):
         self.depurador = depurador.Depurador(self.obtener_lienzo(), self.fps)
         self.mouse_x = 0
         self.mouse_y = 0
+        self.camara_x = 0
+        self.camara_y = 0
 
     def iniciar_ventana(self, ancho, alto, titulo, pantalla_completa):
         self.ancho = ancho
@@ -516,8 +532,8 @@ class QtBase(motor.Motor):
     def obtener_actor(self, imagen, x, y):
         return QtActor(imagen, x, y)
 
-    def obtener_texto(self, texto):
-        return QtTexto(texto)
+    def obtener_texto(self, texto, magnitud):
+        return QtTexto(texto, magnitud, self)
 
     def obtener_posicion_del_mouse(self):
         #return (self.mouse_x, self.mouse_y)
@@ -611,12 +627,11 @@ class QtBase(motor.Motor):
         self.ventana.update()
 
     def definir_centro_de_la_camara(self, x, y):
-        view = self.ventana.GetDefaultView()
-        view.SetCenter(x, y)
+        self.camara_x = x
+        self.camara_y = y
 
     def obtener_centro_de_la_camara(self):
-        view = self.ventana.GetDefaultView()
-        return view.GetCenter()
+        return (self.camara_x, self.camara_y)
 
     def pintar(self, color):
         pass
@@ -683,6 +698,7 @@ class QtBase(motor.Motor):
         self.canvas.end()
 
     def timerEvent(self, event):
+
         try:
             self.realizar_actualizacion_logica()
         except Exception as e:
@@ -723,6 +739,9 @@ class QtBase(motor.Motor):
         x, y = utils.convertir_de_posicion_fisica_relativa(e.pos().x()/escala, e.pos().y()/escala)
         eventos.termina_click.send("Qt::mouseReleaseEvent", x=x, y=y, dx=0, dy=0)
 
+    def wheelEvent(self, e):
+        eventos.mueve_rueda.send("ejecutar", delta=e.delta() / 120)
+
     def mouseMoveEvent(self, e):
         escala = self.escala()
         x, y = utils.convertir_de_posicion_fisica_relativa(e.pos().x()/escala, e.pos().y()/escala)
@@ -751,6 +770,13 @@ class QtBase(motor.Motor):
             QtCore.Qt.Key_Down: simbolos.ABAJO,
             QtCore.Qt.Key_Space: simbolos.SELECCION,
             QtCore.Qt.Key_Return: simbolos.SELECCION,
+            QtCore.Qt.Key_F1: simbolos.F1,
+            QtCore.Qt.Key_F2: simbolos.F2,
+            QtCore.Qt.Key_F3: simbolos.F3,
+            QtCore.Qt.Key_F4: simbolos.F4,
+            QtCore.Qt.Key_F5: simbolos.F5,
+            QtCore.Qt.Key_F6: simbolos.F6,
+            QtCore.Qt.Key_F7: simbolos.F7,
             QtCore.Qt.Key_F8: simbolos.F8,
             QtCore.Qt.Key_F9: simbolos.F9,
             QtCore.Qt.Key_F10: simbolos.F10,
